@@ -66,7 +66,7 @@ Sphinx domain for ``cylc`` configurations.
 
      .. cylc:setting:: foo
 
-        a setting called ``foo``.
+        A setting called ``foo``.
 
         We can use relative references to link to other sections in the
         same configuration tree. Just use ``..`` to back up a level
@@ -81,14 +81,14 @@ Sphinx domain for ``cylc`` configurations.
 
      .. cylc:section:: bar
 
-        a section called ``bar``.
+        A section called ``bar``.
 
         Here's a link to :cylc:conf:`this section <my-conf1.cylc[bar]>`, note
         we re-named the target using the sphinx/rst ``name <target>`` syntax.
 
         .. cylc:setting:: pub
 
-           a setting called ``pub``
+           A setting called ``pub``
 
            .. cylc:value:: integer
 
@@ -103,6 +103,10 @@ Sphinx domain for ``cylc`` configurations.
 
               an iso8601 duration.
 
+        .. cylc:setting:: a/b/c
+
+           A setting with a ``/`` in the name.
+
 
 Auto Documenters
 ----------------
@@ -200,8 +204,8 @@ __version__ = '1.0.0'
 
 def setup(app):
     """Sphinx plugin setup function."""
-    app.add_lexer('cylc', CylcLexer())
-    app.add_lexer('cylc-graph', CylcGraphLexer())
+    app.add_lexer('cylc', CylcLexer)
+    app.add_lexer('cylc-graph', CylcGraphLexer)
     app.add_domain(CylcDomain)
     app.add_domain(ParsecDomain)
     app.add_directive('auto-cylc-conf', CylcAutoDirective)
